==> axiom-1.2.21-src.zip: axiom-1.2.21/testing/spring-ws-testsuite/src/main/java/org/apache/axiom/ts/springws/scenario/soapaction/SoapActionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.springws.scenario.soapaction;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.dom.DOMSource;

import org.apache.axiom.ts.soap.SOAPSpec;
import org.apache.axiom.ts.springws.scenario.ScenarioConfig;
import org.apache.axiom.ts.springws.scenario.ScenarioTestCase;
import org.springframework.ws.client.core.WebServiceTemplate;
import org.springframework.ws.soap.client.core.SoapActionCallback;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class SoapActionTest extends ScenarioTestCase {
    public SoapActionTest(ScenarioConfig config, SOAPSpec spec) {
        super(config, spec);
    }
    
    @Override
    protected void runTest() throws Throwable {
        DocumentBuilder documentBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
        Document requestDocument = documentBuilder.newDocument();
        Element request = requestDocument.createElementNS("urn:test", "p:Echo");
        request.setTextContent("Hello");
        Document responseDocument = documentBuilder.newDocument();
        context.getBean(WebServiceTemplate.class).sendSourceAndReceiveToResult(
                new DOMSource(request),
                new SoapActionCallback("http://www.example.com/echo"),
                new DOMResult(responseDocument));
        Element response = responseDocument.getDocumentElement();
        assertEquals("urn:test", response.getNamespaceURI());
        assertEquals("Echo", response.getLocalName());
        assertEquals("Hello", response.getTextContent());
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/spring-ws-testsuite/src/main/java/org/apache/axiom/ts/springws/scenario/soapaction/SoapActionTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.springws.scenario.soapaction;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.transform.dom.DOMResult;
import javax.xml.transform.dom.DOMSource;

import org.apache.axiom.ts.soap.SOAPSpec;
import org.apache.axiom.ts.springws.scenario.ScenarioConfig;
import org.apache.axiom.ts.springws.scenario.ScenarioTestCase;
import org.springframework.ws.client.core.WebServiceTemplate;
import org.springframework.ws.soap.client.core.SoapActionCallback;
import org.w3c.dom.Document;
import org.w3c.dom.Element;

public class SoapActionTest extends ScenarioTestCase {
    public SoapActionTest(ScenarioConfig config, SOAPSpec spec) {
        super(config, spec);
    }

    @Override
    protected void runTest() throws Throwable {
        DocumentBuilder documentBuilder = DocumentBuilderFactory.newInstance().newDocumentBuilder();
        Document requestDocument = documentBuilder.newDocument();
        Element request = requestDocument.createElementNS("urn:test", "p:Echo");
        request.setTextContent("Hello");
        Document responseDocument = documentBuilder.newDocument();
        context.getBean(WebServiceTemplate.class)
                .sendSourceAndReceiveToResult(
                        new DOMSource(request),
                        new SoapActionCallback("http://www.example.com/echo"),
                        new DOMResult(responseDocument));
        Element response = responseDocument.getDocumentElement();
        assertEquals("urn:test", response.getNamespaceURI());
        assertEquals("Echo", response.getLocalName());
        assertEquals("Hello", response.getTextContent());
    }
}
